pub struct ParsedWorkerInvocation { /* private fields */ }Implementations
Sourceimpl ParsedWorkerInvocation
impl ParsedWorkerInvocation
pub fn request_id(&self) -> &str
pub fn runtime_generation_id(&self) -> &str
pub fn plugin_instance_id(&self) -> IpcResult<&str>
Sourcepub fn session_scope(&self) -> IpcResult<Option<SessionScope>>
pub fn session_scope(&self) -> IpcResult<Option<SessionScope>>
Returns the exact session scope when the invocation is session-bound. Background invocations may omit both session-specific hashes. A partial session identity is rejected instead of being treated as unscoped.
pub fn context(&self) -> IpcResult<WorkerInvocationContext>
pub fn identity(&self) -> IpcResult<WorkerInvocationIdentity>
pub fn validate_worker_contract(&self) -> IpcResult<()>
pub fn worker_request_json_v2(&self) -> IpcResult<String>
pub fn memory_limit_bytes(&self) -> IpcResult<usize>
pub fn replay_key(&self) -> IpcResult<WorkerLeaseReplayKey>
pub fn storage_handle_grant(&self, store_id: &str) -> IpcResult<String>
pub fn validate_storage_broker_access( &self, store_id: &str, operation: &str, ) -> IpcResult<()>
pub fn storage_broker_scope(&self, store_id: &str) -> IpcResult<String>
pub fn validate_network_broker_access( &self, connector_id: &str, transport: &str, operation: &str, http_method: &str, ) -> IpcResult<()>
pub fn network_broker_scope( &self, connector_id: &str, transport: &str, ) -> IpcResult<String>
Sourceimpl ParsedWorkerInvocation
impl ParsedWorkerInvocation
pub fn verify_runtime_lease_signature( &self, public_keys: &[RuntimeLeasePublicKey], ) -> IpcResult<()>
Sourceimpl ParsedWorkerInvocation
impl ParsedWorkerInvocation
pub fn validate_runtime_lease(&self, now_unix_ms: i64) -> IpcResult<()>
Sourceimpl ParsedWorkerInvocation
impl ParsedWorkerInvocation
pub fn target_hash(&self) -> IpcResult<String>